Class: MasterCard::API::Qkr::Card
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Qkr::Card
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/qkr/card.rb
Class Method Summary collapse
Instance Method Summary collapse
Class Method Details
.create(mapObj) ⇒ Object
63 64 65 66 67 68 69 70 71 |
# File 'lib/mastercard/api/qkr/card.rb', line 63 def self.create(mapObj) # #Creates object of type Card # #@param Dict mapObj, containing the required parameters to create a new object #@return [Card] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("b864a120-291f-4544-91c3-55a0e1a2a5fc", Card.new(mapObj)) end |
.deleteById(id, map = nil) ⇒ Object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/mastercard/api/qkr/card.rb', line 82 def self.deleteById(id, map = nil) #Delete object of type Card by id #@param [String] id #@param [Dict] map, containing additional parameters #@return [Card] of the response of the deleted instance. #@raise [APIException] an exception from the response status mapObj = Card.new if !(id.nil? || id.to_s.empty?) mapObj.set("id", id) end if !map.nil? if map.instance_of? RequestMap mapObj.setAll(map.getObject()) else mapObj.setAll(map) end end return self.execute("f98258a6-6a56-4c47-9e6b-b051b3d8ffbb", mapObj) end |
.query(criteria) ⇒ Object
127 128 129 130 131 132 133 134 135 136 |
# File 'lib/mastercard/api/qkr/card.rb', line 127 def self.query(criteria) # #Query objects of type Card by id and optional criteria #@param [Dict] criteria #@return [Card] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("cedbdad5-c7cd-4e88-aa35-8941458b59bf",Card.new(criteria)) end |
Instance Method Details
#delete ⇒ Object
107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/mastercard/api/qkr/card.rb', line 107 def delete # #Delete object of type Card #@param [String] id #@return [Card] of the response of the deleted instance. #@raise [APIException] an exception from the response status # return self.class.execute("f98258a6-6a56-4c47-9e6b-b051b3d8ffbb", self) end |
#update ⇒ Object
140 141 142 143 144 145 146 147 148 |
# File 'lib/mastercard/api/qkr/card.rb', line 140 def update # #Updates an object of type Card # #@return [Card] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("406e8ff1-6cd5-44cf-ab40-ba1094595118",self) end |