Class: MasterCard::API::Qkr::Lightbox

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/qkr/lightbox.rb

Class Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



61
62
63
64
65
66
67
68
69
# File 'lib/mastercard/api/qkr/lightbox.rb', line 61

def self.create(mapObj)
	#
	#Creates object of type Lightbox
	#
	#@param Dict mapObj, containing the required parameters to create a new object
	#@return [Lightbox] of the response of created instance.
	#@raise [APIException] an exception from the response status
	return self.execute("94955969-59de-4ee4-a621-4574fa2386af", Lightbox.new(mapObj))
end

.read(id, criteria = nil) ⇒ Object



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/mastercard/api/qkr/lightbox.rb', line 81

def self.read(id, criteria = nil)
	#
	#Returns objects of type Lightbox by id and optional criteria
	#@param [String] id
	#@param [Dict] criteria
	#@return [Lightbox] object representing the response
	#@raise [APIException] an exception from the response status

	mapObj = Lightbox.new
	if !(id.nil? || id.to_s.empty?)
	  mapObj.set("id", id)
	end
	if !criteria.nil?
		if criteria.instance_of? RequestMap
		  mapObj.setAll(criteria.getObject())
		else
		  mapObj.setAll(criteria)
		end
	end

	return self.execute("e268a60a-425c-47a6-9f27-aba2d450e139",Lightbox.new(mapObj))
end