Class: MasterCard::API::Qkr::User
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Qkr::User
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/qkr/user.rb
Class Method Summary collapse
Instance Method Summary collapse
Class Method Details
.create(mapObj) ⇒ Object
62 63 64 65 66 67 68 69 70 |
# File 'lib/mastercard/api/qkr/user.rb', line 62 def self.create(mapObj) # #Creates object of type User # #@param Dict mapObj, containing the required parameters to create a new object #@return [User] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("226b99f8-4d0b-45c8-b0f1-e5d5c293bad4", User.new(mapObj)) end |
.query(criteria) ⇒ Object
83 84 85 86 87 88 89 90 91 92 |
# File 'lib/mastercard/api/qkr/user.rb', line 83 def self.query(criteria) # #Query objects of type User by id and optional criteria #@param [Dict] criteria #@return [User] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("57a52cca-7777-4ac8-b335-2d1f09996675",User.new(criteria)) end |
Instance Method Details
#update ⇒ Object
96 97 98 99 100 101 102 103 104 |
# File 'lib/mastercard/api/qkr/user.rb', line 96 def update # #Updates an object of type User # #@return [User] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("96611e40-119a-4448-96fa-121e5e1b3b14",self) end |